@@ -3,7 +3,7 @@ from typing import Optional
 from .open_clip import OpenCLIP
 
 
-def CLIP(architecture: str, precision: Optional[str] = None, jit=True):
+def CLIP(architecture: str, precision: Optional[str] = None):
     """
     Args:
         architecture (str): name of the clip model. Available models are:
@@ -16,7 +16,6 @@ def CLIP(architecture: str, precision: Optional[str] = None, jit=True):
             - ViT-B-16
             - ViT-L-14
             - ViT-L-14-336px
-
         precision (str): precision of the model. Options are "fp32" and "fp16"
     """
     if "-quickgelu" not in architecture and architecture in [
@@ -25,7 +24,7 @@ def CLIP(architecture: str, precision: Optional[str] = None, jit=True):
         "ViT-B-32",
     ]:
         architecture = architecture + "-quickgelu"
-    return OpenCLIP(architecture, "openai", precision, jit=jit)
+    return OpenCLIP(architecture, "openai", precision)
 
 
 def test_clip():
